@@ -2,6 +2,7 @@ import base64
 import hashlib
 import hmac
 import ipaddress
+import json
 import os
 from typing import List, Optional
 
@@ -56,6 +57,16 @@ class ClientUtils:
 
     @staticmethod
     def compute_signature(client_secret: str, method: str, path: str, timestamp: str, body: bytes) -> str:
+        """
+        Used by the server
+
+        :param client_secret:
+        :param method:
+        :param path:
+        :param timestamp:
+        :param body:
+        :return:
+        """
         body_hash = hashlib.sha256(body).hexdigest()
 
         canonical_msg = f"{method}\n{path}\n{str(timestamp)}\n{body_hash}"
@@ -70,6 +81,57 @@ class ClientUtils:
 
         return expected_signature_b64
 
+    @staticmethod
+    def create_auth_headers(client_id: str, client_secret: str, method: str, path: str, body: dict = None) -> dict:
+        """
+        Used by the client
+
+        :param client_id:
+        :param client_secret:
+        :param method:
+        :param path:
+        :param body:
+        :return:
+        """
+        timestamp = str(Utils.datetime_now().timestamp())
+        signature = ClientUtils.generate_signature(
+            method=method,
+            path=path,
+            body=body or {},
+            client_secret=client_secret,
+            timestamp=timestamp,
+        )
+        return {
+            "X-Client-ID": client_id,
+            "X-Timestamp": timestamp,
+            "X-Signature": signature,
+        }
+
+    @staticmethod
+    def generate_signature(client_secret: str, method: str, path: str, body: dict, timestamp: str) -> str:
+        """
+        Used by the client
+
+        :param client_secret:
+        :param method:
+        :param path:
+        :param body:
+        :param timestamp:
+        :return:
+        """
+        body_json = json.dumps(body)
+        body_hash = hashlib.sha256(body_json.encode()).hexdigest()
+
+        canonical_string = f"{method.upper()}\n{path}\n{timestamp}\n{body_hash}"
+
+        signature = hmac.new(
+            key=client_secret.encode(),
+            msg=canonical_string.encode(),
+            digestmod=hashlib.sha256
+        ).digest()
+
+        return base64.b64encode(signature).decode()
+
     @staticmethod
     async def verify_signature(request: Request, client_secret: str):
         client_id = request.headers.get("x-client-id")
