@@ -60,10 +60,19 @@ class Utils:
         return Utils.datetime_now() - delta
 
     @staticmethod
-    def get_time_diff_sec(start_datetime: datetime):
+    def datetime_now_diff_in_sec(start_datetime: datetime):
         if not datetime:
             return 0
-        return (Utils.datetime_now() - start_datetime).total_seconds()
+
+        if isinstance(start_datetime, str):
+            start_datetime = datetime.fromisoformat(start_datetime)
+
+        if not start_datetime.tzinfo:
+            start_datetime = start_datetime.replace(tzinfo=timezone.utc)
+
+        value = (Utils.datetime_now() - start_datetime).total_seconds()
+
+        return round(abs(value))
 
     @staticmethod
     def format_datetime(in_datetime: Union[str, datetime]) -> Optional[datetime]:
