@@ -130,7 +130,7 @@ class InvalidResourceStateException(AppodusBaseException):
 # ────────────────────────────────
 
 class ValidationException(AppodusBaseException):
-    def __init__(self, errors: list, message: str = None, context: Optional[ExceptionContext] = None):
+    def __init__(self, errors: list = None, message: str = None, context: Optional[ExceptionContext] = None):
         super().__init__(
             message=message or "Validation failed",
             status_code=status.HTTP_422_UNPROCESSABLE_ENTITY,
@@ -139,6 +139,15 @@ class ValidationException(AppodusBaseException):
         )
         self.details = errors
 
+class TemplateRenderingException(AppodusBaseException):
+    def __init__(self, message: str = None, context: Optional[ExceptionContext] = None):
+        super().__init__(
+            message=message or "Template rendering failed",
+            status_code=status.HTTP_422_UNPROCESSABLE_ENTITY,
+            code="TEMPLATE_RENDERING_ERROR",
+            context=context
+        )
+
 
 # ────────────────────────────────
 # System / Server Errors
@@ -183,6 +192,26 @@ class TimeoutException(AppodusBaseException):
         )
 
 
+class RateLimitException(AppodusBaseException):
+    def __init__(self, service: str, message: str = None):
+        super().__init__(
+            message=message or f"Rate limited while calling {service}",
+            status_code=status.HTTP_429_TOO_MANY_REQUESTS,
+            code="RATE_LIMIT_ERROR",
+            context=ExceptionContext(service=service)
+        )
+
+
+class InsufficientBalanceException(AppodusBaseException):
+    def __init__(self, service: str, message: str = None):
+        super().__init__(
+            message=message or f"Insufficient notice while calling {service}",
+            status_code=status.HTTP_402_PAYMENT_REQUIRED,
+            code="INSUFFICIENT_BALANCE_ERROR",
+            context=ExceptionContext(service=service)
+        )
+
+
 # ────────────────────────────────
 # Payments / Finance
 # ────────────────────────────────
